@@ -1259,7 +1259,7 @@ bool RPackageLister::updateCache(pkgAcquireStatus *status, string &error)
       return false;
 
    // Run it
-   if (Fetcher.Run(50000) == pkgAcquire::Failed)
+   if (Fetcher.Run() == pkgAcquire::Failed)
       return false;
 
 
@@ -1344,7 +1344,7 @@ bool RPackageLister::commitChanges(pkgAcquireStatus *status,
    while (1) {
       bool Transient = false;
 
-      if (fetcher.Run(50000) == pkgAcquire::Failed)
+      if (fetcher.Run() == pkgAcquire::Failed)
          goto gave_wood;
 
       string serverError;
@@ -1743,15 +1743,18 @@ bool RPackageLister::readSelections(istream &in)
            I != actionMap.end(); I++) {
          Pkg = Cache.FindPkg((*I).first);
          if (Pkg.end() == false) {
-            Fix.Clear(Pkg);
-            Fix.Protect(Pkg);
+	    Fix.Clear(Pkg);
+	    Fix.Protect(Pkg);
             switch ((*I).second) {
                case ACTION_INSTALL:
-                  Cache.MarkInstall(Pkg, true);
+		  if(_config->FindB("Volatile::SetSelectionsNoFix","false"))
+		     Cache.MarkInstall(Pkg, false);
+		  else
+		     Cache.MarkInstall(Pkg, true);
                   break;
 
                case ACTION_UNINSTALL:
-                  Fix.Remove(Pkg);
+		  Fix.Remove(Pkg);
                   Cache.MarkDelete(Pkg, false);
                   break;
             }
